@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
-our $DATE = '2015-10-22'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2016-03-09'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -177,8 +177,8 @@ sub BUILD {
     my ($self, $args) = @_;
 
     if ($ENV{ANSITABLE_STYLE_SETS}) {
-        require JSON;
-        my $sets = JSON::decode_json($ENV{ANSITABLE_STYLE_SETS});
+        require JSON::MaybeXS;
+        my $sets = JSON::MaybeXS::decode_json($ENV{ANSITABLE_STYLE_SETS});
         croak "ANSITABLE_STYLE_SETS must be an array"
             unless ref($sets) eq 'ARRAY';
         for my $set (@$sets) {
@@ -191,8 +191,8 @@ sub BUILD {
     }
 
     if ($ENV{ANSITABLE_STYLE}) {
-        require JSON;
-        my $s = JSON::decode_json($ENV{ANSITABLE_STYLE});
+        require JSON::MaybeXS;
+        my $s = JSON::MaybeXS::decode_json($ENV{ANSITABLE_STYLE});
         for my $k (keys %$s) {
             my $v = $s->{$k};
             croak "Unknown table style '$k' in ANSITABLE_STYLE environment, ".
@@ -708,8 +708,8 @@ sub _read_style_envs {
     next if $self->{_read_style_envs}++;
 
     if ($ENV{ANSITABLE_COLUMN_STYLES}) {
-        require JSON;
-        my $ss = JSON::decode_json($ENV{ANSITABLE_COLUMN_STYLES});
+        require JSON::MaybeXS;
+        my $ss = JSON::MaybeXS::decode_json($ENV{ANSITABLE_COLUMN_STYLES});
         croak "ANSITABLE_COLUMN_STYLES must be a hash"
             unless ref($ss) eq 'HASH';
         for my $col (keys %$ss) {
@@ -727,8 +727,8 @@ sub _read_style_envs {
     }
 
     if ($ENV{ANSITABLE_ROW_STYLES}) {
-        require JSON;
-        my $ss = JSON::decode_json($ENV{ANSITABLE_ROW_STYLES});
+        require JSON::MaybeXS;
+        my $ss = JSON::MaybeXS::decode_json($ENV{ANSITABLE_ROW_STYLES});
         croak "ANSITABLE_ROW_STYLES must be a hash"
             unless ref($ss) eq 'HASH';
         for my $row (keys %$ss) {
@@ -745,8 +745,8 @@ sub _read_style_envs {
     }
 
     if ($ENV{ANSITABLE_CELL_STYLES}) {
-        require JSON;
-        my $ss = JSON::decode_json($ENV{ANSITABLE_CELL_STYLES});
+        require JSON::MaybeXS;
+        my $ss = JSON::MaybeXS::decode_json($ENV{ANSITABLE_CELL_STYLES});
         croak "ANSITABLE_CELL_STYLES must be a hash"
             unless ref($ss) eq 'HASH';
         for my $cell (keys %$ss) {
@@ -1671,7 +1671,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.46 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2015-10-22.
+This document describes version 0.47 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2016-03-09.
 
 =head1 SYNOPSIS
 
@@ -2486,90 +2486,6 @@ Apply a style set. See L</"STYLE SETS"> for more details.
 
 Render table.
 
-=head1 ENVIRONMENT
-
-=head2 COLOR => BOOL
-
-Can be used to set default value for the C<color> attribute.
-
-=head2 COLOR_DEPTH => INT
-
-Can be used to set default value for the C<color_depth> attribute.
-
-=head2 BOX_CHARS => BOOL
-
-Can be used to set default value for the C<box_chars> attribute.
-
-=head2 UTF8 => BOOL
-
-Can be used to set default value for the C<utf8> attribute.
-
-=head2 COLUMNS => INT
-
-Can be used to override terminal width detection.
-
-=head2 ANSITABLE_BORDER_STYLE => STR
-
-Can be used to set default value for C<border_style> attribute.
-
-=head2 ANSITABLE_COLOR_THEME => STR
-
-Can be used to set default value for C<border_style> attribute.
-
-=head2 ANSITABLE_STYLE => JSON
-
-Can be used to set table's most attributes. Value should be a JSON-encoded hash
-of C<< attr => val >> pairs. Example:
-
- % ANSITABLE_STYLE='{"show_row_separator":1}' ansitable-list-border-styles
-
-will display table with row separator lines after every row.
-
-=head2 WRAP => BOOL
-
-Can be used to set default value for the C<wrap> column style.
-
-=head2 ANSITABLE_COLUMN_STYLES => JSON
-
-Can be used to set per-column styles. Interpreted right before draw(). Value
-should be a JSON-encoded hash of C<< col => {style => val, ...} >> pairs.
-Example:
-
- % ANSITABLE_COLUMN_STYLES='{"2":{"type":"num"},"3":{"type":"str"}}' ansitable-list-border-styles
-
-will display the bool columns as num and str instead.
-
-=head2 ANSITABLE_ROW_STYLES => JSON
-
-Can be used to set per-row styles. Interpreted right before draw(). Value should
-be a JSON-encoded a hash of C<< row_num => {style => val, ...} >> pairs.
-Example:
-
- % ANSITABLE_ROW_STYLES='{"0":{"bgcolor":"000080","vpad":1}}' ansitable-list-border-styles
-
-will display the first row with blue background color and taller height.
-
-=head2 ANSITABLE_CELL_STYLES => JSON
-
-Can be used to set per-cell styles. Interpreted right before draw(). Value
-should be a JSON-encoded a hash of C<< "row_num,col" => {style => val, ...} >>
-pairs. Example:
-
- % ANSITABLE_CELL_STYLES='{"1,1":{"bgcolor":"008000"}}' ansitable-list-border-styles
-
-will display the second-on-the-left, second-on-the-top cell with green
-background color.
-
-=head2 ANSITABLE_STYLE_SETS => JSON
-
-Can be used to apply style sets. Value should be a JSON-encoded array. Each
-element must be a style set name or a 2-element array containing style set name
-and its arguments (C<< [$name, \%args] >>). Example:
-
- % ANSITABLE_STYLE_SETS='[["AltRow",{"odd_bgcolor":"003300"}]]'
-
-will display table with row separator lines after every row.
-
 =head1 FAQ
 
 =head2 General
@@ -2874,6 +2790,106 @@ Or, you can use the L<Text::ANSITable::StyleSet::AltRow> style set:
 
  $t->apply_style_set(AltRow => {even_bgcolor=>'202020'});
 
+=head1 ENVIRONMENT
+
+=head2 COLOR => BOOL
+
+Can be used to set default value for the C<color> attribute.
+
+=head2 COLOR_DEPTH => INT
+
+Can be used to set default value for the C<color_depth> attribute.
+
+=head2 BOX_CHARS => BOOL
+
+Can be used to set default value for the C<box_chars> attribute.
+
+=head2 UTF8 => BOOL
+
+Can be used to set default value for the C<utf8> attribute.
+
+=head2 COLUMNS => INT
+
+Can be used to override terminal width detection.
+
+=head2 ANSITABLE_BORDER_STYLE => STR
+
+Can be used to set default value for C<border_style> attribute.
+
+=head2 ANSITABLE_COLOR_THEME => STR
+
+Can be used to set default value for C<border_style> attribute.
+
+=head2 ANSITABLE_STYLE => str(json)
+
+Can be used to set table's most attributes. Value should be a JSON-encoded hash
+of C<< attr => val >> pairs. Example:
+
+ % ANSITABLE_STYLE='{"show_row_separator":1}' ansitable-list-border-styles
+
+will display table with row separator lines after every row.
+
+=head2 WRAP => BOOL
+
+Can be used to set default value for the C<wrap> column style.
+
+=head2 ANSITABLE_COLUMN_STYLES => str(json)
+
+Can be used to set per-column styles. Interpreted right before draw(). Value
+should be a JSON-encoded hash of C<< col => {style => val, ...} >> pairs.
+Example:
+
+ % ANSITABLE_COLUMN_STYLES='{"2":{"type":"num"},"3":{"type":"str"}}' ansitable-list-border-styles
+
+will display the bool columns as num and str instead.
+
+=head2 ANSITABLE_ROW_STYLES => str(json)
+
+Can be used to set per-row styles. Interpreted right before draw(). Value should
+be a JSON-encoded a hash of C<< row_num => {style => val, ...} >> pairs.
+Example:
+
+ % ANSITABLE_ROW_STYLES='{"0":{"bgcolor":"000080","vpad":1}}' ansitable-list-border-styles
+
+will display the first row with blue background color and taller height.
+
+=head2 ANSITABLE_CELL_STYLES => str(json)
+
+Can be used to set per-cell styles. Interpreted right before draw(). Value
+should be a JSON-encoded a hash of C<< "row_num,col" => {style => val, ...} >>
+pairs. Example:
+
+ % ANSITABLE_CELL_STYLES='{"1,1":{"bgcolor":"008000"}}' ansitable-list-border-styles
+
+will display the second-on-the-left, second-on-the-top cell with green
+background color.
+
+=head2 ANSITABLE_STYLE_SETS => str(json)
+
+Can be used to apply style sets. Value should be a JSON-encoded array. Each
+element must be a style set name or a 2-element array containing style set name
+and its arguments (C<< [$name, \%args] >>). Example:
+
+ % ANSITABLE_STYLE_SETS='[["AltRow",{"odd_bgcolor":"003300"}]]'
+
+will display table with row separator lines after every row.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSITable>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Text-ANSITable>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 =head2 Related to Text::ANSITable family
@@ -2905,29 +2921,13 @@ L<Table::Simple>
 
 Unix command B<column> (e.g. C<column -t>).
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSITable>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
